=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-06-16 17:37:00 +0000
+++ drizzled/drizzled.cc	2010-06-21 05:45:27 +0000
@@ -28,6 +28,8 @@
 #include <signal.h>
 #include <limits.h>
 
+#include <boost/program_options.hpp>
+
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/internal/my_bit.h"
 #include <drizzled/my_hash.h>
@@ -125,6 +127,8 @@
 #define MAX_MEM_TABLE_SIZE SIZE_MAX
 
 using namespace std;
+namespace po=boost::program_options;
+
 
 namespace drizzled
 {
@@ -370,6 +374,8 @@
 
 static void usage(void);
 void close_connections(void);
+
+po::options_description long_options("Allowed Options");
  
 /****************************************************************************
 ** Code to end drizzled
@@ -854,7 +860,7 @@
   ha_init_errors();
 
   if (plugin_init(plugins, &defaults_argc, defaults_argv,
-                  ((opt_help) ? true : false)))
+                  ((opt_help) ? true : false), long_options))
   {
     errmsg_printf(ERRMSG_LVL_ERROR, _("Failed to initialize plugins."));
     unireg_abort(1);
@@ -1385,7 +1391,7 @@
      puts("");
  
      /* Print out all the options including plugin supplied options */
-     my_print_help_inc_plugins(my_long_options);
+     my_print_help_inc_plugins(my_long_options, long_options);
   }
 }
 
@@ -1755,6 +1761,7 @@
   internal::convert_dirname(buff,buff,NULL);
   (void) internal::my_load_path(language,language,buff);
 
+  if (not opt_help and not opt_help_extended)
   {
     char *tmp_string;
     struct stat buf;

=== modified file 'drizzled/module/loader.cc'
--- drizzled/module/loader.cc	2010-06-20 19:05:15 +0000
+++ drizzled/module/loader.cc	2010-06-21 19:10:19 +0000
@@ -164,9 +164,11 @@
 static bool plugin_load_list(module::Registry &registry,
                              memory::Root *tmp_root, int *argc, char **argv,
                              const set<string> &plugin_list,
+                             po::options_description &long_options,
                              bool builtin= false);
 static int test_plugin_options(memory::Root *, module::Module *,
-                               int *, char **);
+                               int *, char **,
+                               po::options_description &long_options);
 static void unlock_variables(Session *session, struct system_variables *vars);
 static void cleanup_variables(Session *session, struct system_variables *vars);
 static void plugin_vars_free_values(sys_var *vars);
@@ -250,7 +252,8 @@
 */
 static bool plugin_add(module::Registry &registry, memory::Root *tmp_root,
                        module::Library *library,
-                       int *argc, char **argv)
+                       int *argc, char **argv,
+                       po::options_description &long_options)
 {
   if (! initialized)
     return true;
@@ -280,7 +283,7 @@
   if (tmp == NULL)
     return true;
 
-  if (!test_plugin_options(tmp_root, tmp, argc, argv))
+  if (!test_plugin_options(tmp_root, tmp, argc, argv, long_options))
   {
     registry.add(tmp);
     return false;
@@ -380,7 +383,8 @@
 */
 bool plugin_init(module::Registry &registry,
                  int *argc, char **argv,
-                 bool skip_init)
+                 bool skip_init,
+                 po::options_description &long_options)
 {
   module::Module *module;
   memory::Root tmp_root(4096);
@@ -430,7 +434,7 @@
   */
   const set<string> builtin_list_set(builtin_list.begin(), builtin_list.end());
   load_failed= plugin_load_list(registry, &tmp_root, argc, argv,
-                                builtin_list_set, true);
+                                builtin_list_set, long_options, true);
   if (load_failed)
   {
     tmp_root.free_root(MYF(0));
@@ -442,7 +446,7 @@
   
   /* Register all dynamic plugins */
   load_failed= plugin_load_list(registry, &tmp_root, argc, argv,
-                                plugin_list_set);
+                                plugin_list_set, long_options);
   if (load_failed)
   {
     tmp_root.free_root(MYF(0));
@@ -517,6 +521,7 @@
 static bool plugin_load_list(module::Registry &registry,
                              memory::Root *tmp_root, int *argc, char **argv,
                              const set<string> &plugin_list,
+                             po::options_description &long_options,
                              bool builtin)
 {
   module::Library *library= NULL;
@@ -537,7 +542,7 @@
     }
 
     tmp_root->free_root(MYF(memory::MARK_BLOCKS_FREE));
-    if (plugin_add(registry, tmp_root, library, argc, argv))
+    if (plugin_add(registry, tmp_root, library, argc, argv, long_options))
     {
       registry.removeLibrary(plugin_name);
       errmsg_printf(ERRMSG_LVL_ERROR,
@@ -1661,7 +1666,8 @@
 */
 static int test_plugin_options(memory::Root *module_root,
                                module::Module *test_module,
-                               int *argc, char **argv)
+                               int *argc, char **argv,
+                               po::options_description &long_options)
 {
   struct sys_var_chain chain= { NULL, NULL };
   drizzle_sys_var **opt;
@@ -1673,11 +1679,11 @@
 
   if (test_module->getManifest().init_options != NULL)
   {
-    cout << "Calling init_options: " << test_module->getName() << endl;
     po::options_description module_options("Options used by plugins");
     module::option_context opt_ctx(test_module->getName(),
                                    module_options.add_options());
     test_module->getManifest().init_options(opt_ctx);
+    long_options.add(module_options);
 
     po::variables_map &vm= test_module->getVariableMap();
 
@@ -1821,7 +1827,8 @@
 };
 
 
-void my_print_help_inc_plugins(option *main_options)
+void my_print_help_inc_plugins(option *main_options,
+                               po::options_description &long_options)
 {
   module::Registry &registry= module::Registry::singleton();
   vector<option> all_options;
@@ -1839,6 +1846,11 @@
       module::Module *p= (*modules).second;
       ++modules;
 
+      /* If we have an init_options function, we are registering
+         commmand line options that way, so don't do them this way */
+      if (p->getManifest().init_options != NULL)
+        continue;
+
       if (p->getManifest().system_vars == NULL)
         continue;
 
@@ -1876,6 +1888,7 @@
   all_options.push_back(*main_options);
 
   my_print_help(&*(all_options.begin()));
+  cout << long_options << endl;
   my_print_variables(&*(all_options.begin()));
 
   mem_root.free_root(MYF(0));

=== modified file 'drizzled/plugin.h'
--- drizzled/plugin.h	2010-05-18 18:20:56 +0000
+++ drizzled/plugin.h	2010-06-21 04:53:35 +0000
@@ -28,6 +28,7 @@
 
 #include "drizzled/lex_string.h"
 #include "drizzled/xid.h"
+#include <boost/program_options.hpp>
 
 namespace drizzled
 {
@@ -373,8 +374,10 @@
 
 extern bool plugin_init(module::Registry &registry,
                         int *argc, char **argv,
-                        bool skip_init);
-extern void my_print_help_inc_plugins(option *options);
+                        bool skip_init,
+                        boost::program_options::options_description &long_options);
+extern void my_print_help_inc_plugins(option *options,
+                                      boost::program_options::options_description &long_options);
 extern bool plugin_is_ready(const LEX_STRING *name, int type);
 extern void plugin_sessionvar_init(Session *session);
 extern void plugin_sessionvar_cleanup(Session *session);

=== modified file 'tests/valgrind.supp'
--- tests/valgrind.supp	2010-05-19 23:54:42 +0000
+++ tests/valgrind.supp	2010-06-21 15:12:27 +0000
@@ -239,9 +239,9 @@
    This whole codebase is going away, so suppress this annoyance.
    Memcheck:Cond
    fun:_ZN8drizzledL17construct_optionsEPNS_6memory4RootEPNS_6module6ModuleEPNS_6optionE
-   fun:_ZN8drizzledL19test_plugin_optionsEPNS_6memory4RootEPNS_6module6ModuleEPiPPc
-   fun:_ZN8drizzledL16plugin_load_listERNS_6module8RegistryEPNS_6memory4RootEPiPPcRKSt3setISsSt4lessISsESaISsEEb
-   fun:_ZN8drizzled11plugin_initERNS_6module8RegistryEPiPPcb
+   fun:_ZN8drizzledL19test_plugin_optionsEPNS_6memory4RootEPNS_6module6ModuleEPiPPcRN5boost15program_options19options_descriptionE
+   fun:_ZN8drizzledL16plugin_load_listERNS_6module8RegistryEPNS_6memory4RootEPiPPcRKSt3setISsSt4lessISsESaISsEERN5boost15program_options19options_descriptionEb
+   fun:_ZN8drizzled11plugin_initERNS_6module8RegistryEPiPPcbRN5boost15program_options19options_descriptionE
    fun:_ZN8drizzled22init_server_componentsERNS_6module8RegistryE
    fun:main
 }

